\def\fileversion{1.100}
\def\filedate{2022/04/06}

\NeedsTeXFormat{LaTeX2e}

\ProvidesClass{CEAS_EuroGNC_2024}[\filedate\space Version \fileversion\space by Nicolas Fezans]

\newif\if@final
\newif\if@draft
\DeclareOption{final}{\@finaltrue}
\DeclareOption{draft}{\@drafttrue}


\DeclareOption*{
  \PassOptionsToClass{\CurrentOption}{article}%
}
\ProcessOptions\relax
\LoadClass[12pt]{article}
\RequirePackage[a4paper,margin=2.0cm,left=1.75cm,right=1.75cm]{geometry}
\RequirePackage{setspace}
\singlespacing

\setlength{\parskip}{6pt}
\setlength{\parindent}{0.75cm}

%\RequirePackage{setspace}
\if@final
\fi
\if@draft
  \doublespacing
\fi


% begin change from v1.0 to v1.1 (change suggested by Yannic Beyer 
% to prevent issues when using \bm in math mode)
% - use newtxtext and newtxmath instead of mathptmx to avoid doubled letters when using \bm
% - this change was recommended in the following threads
%   -> https://tex.stackexchange.com/questions/424894/doubled-letter-when-i-using-bm
%   -> https://tex.stackexchange.com/questions/117076/how-can-i-get-bold-greek-letters-with-mathptmx
% - mathptmx seems to be obsolete and recommends newtx instead: 
%   -> https://ctan.org/pkg/mathptmx?lang=de

%\RequirePackage{mathptmx} % old package used in v1.0
\RequirePackage{newtxtext,newtxmath} % replacement in v1.1

% end of changed section


\RequirePackage[T1]{fontenc}
\RequirePackage[utf8]{inputenc}

\RequirePackage{bm}

\RequirePackage{wrapfig}

\RequirePackage{enumitem}
\setlist{labelindent=\parindent,leftmargin=*,nosep}
\setlist[enumerate]{label={\arabic*)}}



\RequirePackage[style]{abstract}
\renewcommand{\abstitlestyle}[1]{\noindent\bfseries\normalsize\emph{ABSTRACT}}
\renewcommand{\abstracttextfont}{\noindent\bfseries\normalsize}
\setlength{\absleftindent}{0.0cm}
\setlength{\absrightindent}{0.0cm}




\renewcommand{\maketitle}{%
  \vspace*{-\topskip}      % remove the initial space
  \begingroup
  \centering
  \hrule height \z@        % to avoid the insertion of lineskip glue
  {\vspace*{2cm}\LARGE\textbf\@title\par}
  \vskip\baselineskip
  \endgroup
  \if@draft
    \thispagestyle{empty}
  \fi
  \setcounter{footnote}{0}
}



\RequirePackage[largestsep]{titlesec}
\renewcommand{\thesection}{\arabic{section}}
\renewcommand{\thesubsection}{\thesection.\arabic{subsection}}
\renewcommand{\thesubsubsection}{\thesubsection.\arabic{subsubsection}}

\titleformat{\section}{\Large\bfseries\singlespacing}{\thesection\space\space}{0pt}{}[]
\titlespacing{\section}{0pt}{-4.5ex+18pt}{0pt}


\titleformat{\subsection}{\large\bfseries\singlespacing}{\thesubsection\space\space}{0pt}{}[]
\titlespacing{\subsection}{0pt}{-4.0ex+12pt}{0pt}

\titleformat{\subsubsection}{\large\itshape\singlespacing}{\thesubsubsection\space\space}{0pt}{}[]
\titlespacing{\subsubsection}{0pt}{-4.0ex+12pt}{0pt}

\titleformat{\paragraph}{\normalsize\singlespacing}{\theparagraph\space\space}{0pt}{}[]
\titlespacing{\paragraph}{0pt}{-4.0ex+9pt}{0pt}

\RequirePackage[hyphens]{url}
\RequirePackage[pdfborder={0 0 0}]{hyperref}
\RequirePackage{xcolor}
\RequirePackage[all]{nowidow}
\RequirePackage{soul}



\RequirePackage[tableposition=top]{caption}
\renewcommand{\figurename}{Fig.}
\captionsetup*{font=small,labelfont=bf,textfont=bf,labelsep=quad}
\renewcommand{\arraystretch}{1.2}

\newcommand{\keywords}[1]{\noindent\begin{small}{\textbf{Keywords:}~#1}\end{small}}

\RequirePackage[indentfirst=false,font+=small,leftmargin=1.0cm,rightmargin=1.0cm,vskip=4pt]
{quoting}

\setlength{\abovedisplayskip}{\baselineskip}
\setlength{\belowdisplayskip}{\baselineskip}
\setlength{\abovedisplayshortskip}{\baselineskip}
\setlength{\belowdisplayshortskip}{\baselineskip}

\RequirePackage[sort&compress,numbers]{natbib}
\bibliographystyle{CEAS_EuroGNC_2024}
\renewcommand{\bibfont}{\small}


\RequirePackage{tabularx}

\newcommand{\preauthorlist}{
    \renewcommand{\arraystretch}{1.75}
    \tymax=.666\textwidth\tymin=0cm
    \begin{tabular}{r l}}

\newcommand{\postauthorlist}{
    \end{tabular}
    \renewcommand{\arraystretch}{1.0}}

\newcommand{\affiliation}[1]{&\begin{small}#1\end{small}}


\newenvironment{authorList}[1]{
  \renewcommand{\arraystretch}{1.50}
  \setlength{\tabcolsep}{.00\textwidth}\noindent
  \begin{tabular}{p{#1} p{4mm} p{\textwidth-4mm-#1}}
}
{
  \end{tabular}
  \renewcommand{\arraystretch}{1.0}
  \vskip\baselineskip
}
\newcommand{\addAuthor}[2]{{\textbf{\textcolor[rgb]{0.05,0.05,0.45}{#1}}} & &  \textcolor[rgb]{0.15,0.15,0.35}{\begin{small}#2\end{small}}\\}

\newcommand{\emailAddress}[1]{\textcolor{blue}{\href{mailto:#1}{#1}}}


